
% this matlab code generates the rhs source terms of IBVP3 in the thesis
% for analytical simulation where the UL is deactivated
clear all

clc
close all


syms t x y 

i=0; % 1: no vonvectiom

g=10;
ns0=0.5;
rhoSR=2;
rhoFR=1;
lambda=1;
mu=1;
kF0=1;

u1=y^3/24*t;
u2=0;
w1=y^3*t;
w2=0;
p=1/2-x;

nf0=1-ns0;
gammaFR=g*rhoFR;

v1=diff(u1,t);
v2=diff(u2,t);
v1_t=diff(v1,t);
v2_t=diff(v2,t);



w1_t=diff(w1,t);
w2_t=diff(w2,t);

px=diff(p,x);
py=diff(p,y);

u11=diff(u1,x);
u12=diff(u1,y);
u21=diff(u2,x);
u22=diff(u2,y);

div = u11+u22;
detgradu=u11*u22-u12*u21;

ns=(1-div+detgradu)*ns0;
J=ns0/ns;
nf=1-ns;

kF = kF0*(nf/nf0)

rho=ns*rhoSR+nf*rhoFR;
h=lambda*(1-ns0)^2*(1/(1-ns0)-1/(J-ns0));


T11 = (1-u22)*u11 + (J*u12 + u21)*u12 + (J*u22 - 2*J + 1)*u22 + (J-1) + h/mu;
T12 = (J-J*u11)*u12 + (J-J*u22)*u21;
T21=T12;
T22 = (1-u11)*u22 + (J*u21 + u12)*u21 + (J*u11 - 2*J + 1)*u11 + (J-1) + h/mu;

T11=mu*T11;
T12=mu*T12;
T21=mu*T21;
T22=mu*T22;

divTx = diff(T11,x) + diff(T12,y);
divTy = diff(T21,x) + diff(T22,y);

pv1=rho*v1;  pv1_t = diff(pv1,t);
pv2=rho*v2;  pv2_t = diff(pv2,t);

% for convection

vF1 = w1/nf+v1;
vF2 = w2/nf+v2;

vF11=diff(vF1,x);
vF12=diff(vF1,y);
vF21=diff(vF2,x);
vF22=diff(vF2,y);

convection1x = rhoFR*(vF11*w1 + vF12*w2);
convection1y = rhoFR*(vF21*w1 + vF22*w2);

convection2x = convection1x/nf;
convection2y = convection1y/nf;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5

fu1 = pv1_t + rhoFR*w1_t - divTx + px + convection1x*(1-i);
fu2 = pv2_t + rhoFR*w2_t - divTy + py + convection1y*(1-i);

fw1 = rhoFR*v1_t + rhoFR*diff(w1/nf,t) + gammaFR/kF * w1 + px + convection2x*(1-i);
fw2 = rhoFR*v2_t + rhoFR*diff(w2/nf,t) + gammaFR/kF * w2 + py + convection2y*(1-i);
